This internal function modifies the pooled-over-time dataset generated by the simulate function
to a format suitable for hazard ratio calculation.
hr_helper(i, intcomp, time_name, pools)Data table consisting of failure time information for each individual or the last time point information (for individuals who do not experience an event).
Integer specifying the index intcomp.
List of two numbers indicating a pair of interventions to be compared by a hazard ratio.
Character string specifying the name of the time variable in pools.
Data table containing the simulated values for the covariates, outcome probabilities, competing event probabilities, outcomes, and competing events.